@@ -1,5 +1,6 @@
 from .elements_listener import ElementsActionListener
 import logging
+import asyncio
 # A sample implementation of Abstract imListener class
 # The listener can respond to incoming events if the respective event
 # handler has been implemented
@@ -17,3 +18,14 @@ class ElementsListenerTestImp(ElementsActionListener):
 
     def on_elements_action(self, action):
         logging.debug('element submitted :')
+
+
+
+class AsyncElementsListenerTestImp(ElementsActionListener):
+    """Example implementation of ElementsListener with asynchronous functionality"""
+
+    def __init__(self, sym_bot_client):
+        self.bot_client = sym_bot_client
+
+    async def on_elements_action(self, action):
+        logging.debug('async element submitted :')
