@@ -8,7 +8,7 @@ class MessageProcessor:
         self.message_parser = SymMessageParser()
 
     def process(self, msg):
-        logging.debug('insdie of process')
+        logging.debug('inside of process')
         msg_text = self.message_parser.get_text(msg)
         msg_to_send = dict(
                 message='<messageML>Hello {}, hope you are doing well!</messageML>'.format(self.message_parser.get_im_first_name(msg))
